window.Gleam.initSearch([{"doc":"gtz","title":"gtz","content":"# gtz\nA timezone data provider for Gleam!\n\n[![Package Version](https://img.shields.io/hexpm/v/gtz)](https://hex.pm/packages/gtz)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gtz/)\n\n```sh\ngleam add gtz\ngleam add gtempo@5\n```\n\nThis package was written to be used with the [Tempo](https://hexdocs.pm/gtempo/index.html) package, but could be expanded to provide timezone support for other libraries as well! Contributions are welcome! Currently this package is very simple and only supports converting non-naive datetimes to a specific timezone via Tempo; it does not support constructing new datetimes in a specific timezone or assigning a timezone to an existing naive datetime.\n\nAmbiguous datetimes and DST boundries are not handled explicitly by this package, but instead rely on the target timezone package&#39;s default handling. It seems like the Elixir package prefers the future time and JavaScript prefers the past time for DST boundries. Once ambiguous datetimes are worked out to be a little more explicit or obvious in this package, there will probably be a v1 release.\n\nSupports both the Erlang and JavaScript targets.\n\n#### Converting DateTimes to the Local Timezone\n```gleam\nimport gtz\nimport tempo/datetime\n\npub fn main() {\n  let assert Ok(local_tz) = gtz.local_name() |&gt; gtz.timezone\n\n  datetime.from_unix_utc(1_729_257_776)\n  |&gt; datetime.to_timezone(local_tz)\n  |&gt; datetime.to_string\n}\n// -&gt; &quot;2024-10-18T14:22:56.000+01:00&quot;\n```\n\n#### Converting DateTimes to a Specific Timezone\n\n```gleam\nimport gtz\nimport tempo/datetime\n\npub fn main() {\n  let assert Ok(tz) = gtz.timezone(&quot;America/New_York&quot;)\n\n  datetime.literal(&quot;2024-01-03T05:30:02.334Z&quot;)\n  |&gt; datetime.to_timezone(tz)\n  |&gt; datetime.to_string\n}\n// -&gt; &quot;2024-01-03T00:30:02.334-05:00&quot;\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gtz&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"gtz","title":"local_name","content":"pub fn local_name() -&gt; String\n Returns the name of the host system&#39;s timezone.\n \n ## Examples\n \n \n gtz.local_name()\n // -&gt; &quot;Europe/London&quot;\n \nSynonyms:\ngtz.local_name\ngtz local_name","url":"gtz.html#local_name"},{"doc":"gtz","title":"timezone","content":"pub fn timezone(name: String) -&gt; Result(TimeZoneProvider, Nil)\n Constructs a TimeZoneProvider type to be used with the Tempo package. \n Returns an error if the timezone is not valid.\n \n ## Examples\n \n \n import tempo/datetime\n\n let assert Ok(tz) = gtz.timezone(&quot;America/New_York&quot;)\n datetime.literal(&quot;2024-06-21T06:30:02.334Z&quot;)\n |&gt; datetime.to_timezone(tz)\n |&gt; datetime.to_string\n // -&gt; &quot;2024-01-03T02:30:02.334-04:00&quot;\n \nSynonyms:\ngtz.timezone\ngtz timezone","url":"gtz.html#timezone"},{"doc":"gtz","title":"gtz","content":" Functions to provide simple timezone support for other Gleam datetime libraries.","url":"gtz.html"}]);